Changelog
---------

Unreleased
~~~~~~~~~~
0.1.0 (2015-10-12)
~~~~~~~~~~~~~~~~~~~

- Removes Python 2.x support.
  [href]

0.0.6 (2015-09-25)
~~~~~~~~~~~~~~~~~~~

- Adds onegov.search integration.
  [href]

0.0.5 (2015-09-15)
~~~~~~~~~~~~~~~~~~~

- Add an optional URL to ical exports.
  [msom]

- Cleanup the documentation.
  [msom]

0.0.4 (2015-09-08)
~~~~~~~~~~~~~~~~~~~

- Add cli command for guidle import (experimental).
  [msom]

- Add ical export functions.
  [msom]

0.0.3 (2015-09-03)
~~~~~~~~~~~~~~~~~~~

- Don't delete old event automatically.
  [msom]

0.0.2 (2015-08-28)
~~~~~~~~~~~~~~~~~~~

- Use hstore for tags.
  [msom]

- Filter for current occurrences by default.
  [msom]

- Add autoclean option to add event function.
  [msom]

- Add by_id method for event collections.
  [msom]

- Automatically remove old initiated events.
  [msom]

0.0.1 (2015-08-20)
~~~~~~~~~~~~~~~~~~~

- Initial Release
